==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/InstanceSetReferenceSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.value.InstanceSetReference;
import io.ciera.tool.sql.ooaofooa.value.InstanceSetReferenceSet;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class InstanceSetReferenceSetImpl extends InstanceSet<InstanceSetReferenceSet,InstanceSetReference> implements InstanceSetReferenceSet {

    // attributes
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( InstanceSetReference instancesetreference : this ) instancesetreference.setValue_ID( ref_Value_ID );
    }
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( InstanceSetReference instancesetreference : this ) instancesetreference.setVar_ID( ref_Var_ID );
    }


    // selections
    @Override
    public ValueSet R801_is_a_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( InstanceSetReference instancesetreference : this ) valueset.add( instancesetreference.R801_is_a_Value() );
        return valueset;
    }
    @Override
    public V_VARSet R809_refers_to_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( InstanceSetReference instancesetreference : this ) v_varset.add( instancesetreference.R809_refers_to_V_VAR() );
        return v_varset;
    }


    @Override
    public InstanceSetReference nullElement() {
        return InstanceSetReferenceImpl.EMPTY_INSTANCESETREFERENCE;
    }

    @Override
    public InstanceSetReferenceSet emptySet() {
      return new InstanceSetReferenceSetImpl();
    }

    @Override
    public InstanceSetReferenceSet value() {
        return this;
    }

    @Override
    public List<InstanceSetReference> elements() {
        return Arrays.asList(toArray(new InstanceSetReference[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/InstanceSetReferenceSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.value.InstanceSetReference;
import io.ciera.tool.sql.ooaofooa.value.InstanceSetReferenceSet;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class InstanceSetReferenceSetImpl extends InstanceSet<InstanceSetReferenceSet,InstanceSetReference> implements InstanceSetReferenceSet {

    public InstanceSetReferenceSetImpl() {
    }

    public InstanceSetReferenceSetImpl(Comparator<? super InstanceSetReference> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( InstanceSetReference instancesetreference : this ) instancesetreference.setValue_ID( ref_Value_ID );
    }
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( InstanceSetReference instancesetreference : this ) instancesetreference.setVar_ID( ref_Var_ID );
    }


    // selections
    @Override
    public ValueSet R801_is_a_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( InstanceSetReference instancesetreference : this ) valueset.add( instancesetreference.R801_is_a_Value() );
        return valueset;
    }
    @Override
    public V_VARSet R809_refers_to_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( InstanceSetReference instancesetreference : this ) v_varset.add( instancesetreference.R809_refers_to_V_VAR() );
        return v_varset;
    }


    @Override
    public InstanceSetReference nullElement() {
        return InstanceSetReferenceImpl.EMPTY_INSTANCESETREFERENCE;
    }

    @Override
    public InstanceSetReferenceSet emptySet() {
      return new InstanceSetReferenceSetImpl();
    }

    @Override
    public InstanceSetReferenceSet emptySet(Comparator<? super InstanceSetReference> comp) {
      return new InstanceSetReferenceSetImpl(comp);
    }

    @Override
    public InstanceSetReferenceSet value() {
        return this;
    }

    @Override
    public List<InstanceSetReference> elements() {
        return Arrays.asList(toArray(new InstanceSetReference[0]));
    }

}
